@@ -146,6 +146,8 @@ class ReTextWindow(QMainWindow):
 			self.useWebKit = readFromSettings('useWebKit', bool, default=False)
 			if self.useWebKit:
 				self.actionWebKit.setChecked(True)
+		else:
+			self.useWebKit = False
 		self.actionWpgen = self.act(self.tr('Generate webpages'), trig=self.startWpgen)
 		self.actionShow = self.act(self.tr('Show'), icon='system-file-manager', trig=self.showInDir)
 		self.actionFind = self.act(self.tr('Next'), icon='go-next', shct=QKeySequence.FindNext,
@@ -812,8 +814,8 @@ class ReTextWindow(QMainWindow):
 	
 	def getExportExtensionsList(self):
 		extensions = []
-		for extsprefix in ('/usr', QDir.homePath()+'/.local'):
-			extsdir = QDir(extsprefix+'/share/retext/export-extensions/')
+		for extsprefix in datadirs:
+			extsdir = QDir(extsprefix+'/export-extensions/')
 			if extsdir.exists():
 				for fileInfo in extsdir.entryInfoList(['*.desktop', '*.ini'], QDir.Files | QDir.Readable):
 					extensions.append(self.readExtension(fileInfo.filePath()))
@@ -948,7 +950,7 @@ class ReTextWindow(QMainWindow):
 				defaultExt = convertToUnicode(self.tr('%s files',
 					'Example of final string: Markdown files')) \
 					% markupClass.name + ' (' + str.join(' ',
-					['*'+ext for ext in markupClass.file_extensions]) + ')'
+					('*'+extension for extension in markupClass.file_extensions)) + ')'
 				ext = markupClass.default_extension
 			newFileName = QFileDialog.getSaveFileName(self, self.tr("Save file"), "", defaultExt)
 			if newFileName:
@@ -1211,6 +1213,7 @@ class ReTextWindow(QMainWindow):
 			# For Python 3
 			HtmlDlg.setWindowTitle(winTitle+" ("+self.tr("HTML code")+") \u2014 "+app_name)
 		HtmlDlg.textEdit.setPlainText(htmltext.rstrip())
+		HtmlDlg.hl.rehighlight()
 		HtmlDlg.show()
 		HtmlDlg.raise_()
 		HtmlDlg.activateWindow()
